@@ -18,7 +18,7 @@ from robotoff.utils import get_image_from_url, get_logger, http_session
 logger = get_logger(__name__)
 
 
-DEFAULT_PREDICTION_TYPES: List[PredictionType] = [
+DEFAULT_OCR_PREDICTION_TYPES: List[PredictionType] = [
     PredictionType.label,
     PredictionType.packager_code,
     PredictionType.product_weight,
@@ -27,7 +27,6 @@ DEFAULT_PREDICTION_TYPES: List[PredictionType] = [
     PredictionType.brand,
     PredictionType.store,
     PredictionType.packaging,
-    PredictionType.category,
 ]
 
 IMAGE_IMPORT_PREDICTION_TYPES: List[PredictionType] = [
@@ -43,7 +42,6 @@ IMAGE_IMPORT_PREDICTION_TYPES: List[PredictionType] = [
     PredictionType.nutrient_mention,
     PredictionType.image_lang,
     PredictionType.image_orientation,
-    PredictionType.category,
 ]
 
 
@@ -77,6 +75,7 @@ def get_predictions_from_product_name(
 def get_predictions_from_image(
     barcode: str, image_url: str, ocr_url: str
 ) -> Dict[PredictionType, ProductPredictions]:
+    logger.info(f"Generating OCR predictions from OCR {ocr_url}")
     try:
         ocr_predictions = extract_ocr_predictions(
             ocr_url, IMAGE_IMPORT_PREDICTION_TYPES
@@ -245,7 +244,7 @@ def extract_nutriscore_label(
         return None
 
     if len(results) > 1:
-        logger.warn("more than one nutriscore detected, discarding detections")
+        logger.warning("more than one nutriscore detected, discarding detections")
         return None
 
     result = results[0]
@@ -269,14 +268,12 @@ def extract_nutriscore_label(
     )
 
 
-def predict_objects(
-    barcode: str, image_url: str, server_domain: str
-) -> Dict[str, ObjectDetectionRawResult]:
-    image = get_image_from_url(image_url, error_raise=True, session=http_session)
+def predict_objects(image_url: str) -> Dict[str, ObjectDetectionRawResult]:
+    image = get_image_from_url(image_url, error_raise=False, session=http_session)
     results: Dict[str, ObjectDetectionRawResult] = {}
 
     if image is None:
-        logger.warning("Invalid image: {}".format(image_url))
+        logger.warning(f"Invalid image: {image_url}")
         return results
 
     image.load()
