@@ -101,15 +101,6 @@ def extract_predictions(
     elif prediction_type == PredictionType.image_lang:
         return get_image_lang(content)
 
-    elif prediction_type == PredictionType.category:
-        # TODO: This has been temporarily commented-out as this breaks OCR detection
-        # due to the model not being fully integrated with Robotoff.
-        # return predict_ocr_categories(content)
-        logger.info(
-            "Skipping category OCR prediction until it has been integrated into Robotoff"
-        )
-        return []
-
     else:
         raise ValueError("unknown prediction type: {}".format(prediction_type))
 
