@@ -427,12 +427,6 @@ class ProductStore(metaclass=abc.ABCMeta):
     def __getitem__(self, item):
         pass
 
-    @abc.abstractmethod
-    def is_real_time(self) -> bool:
-        """Return True if the product store return the current version of the product,
-        and not an dumped version as in MemoryProductStore."""
-        pass
-
 
 class MemoryProductStore(ProductStore):
     def __init__(self, store: Dict[str, Product]):
@@ -469,9 +463,6 @@ class MemoryProductStore(ProductStore):
     def __iter__(self) -> Iterator[Product]:
         return iter(self.store.values())
 
-    def is_real_time(self) -> bool:
-        return False
-
 
 class DBProductStore(ProductStore):
     def __init__(self, client: MongoClient):
@@ -498,9 +489,6 @@ class DBProductStore(ProductStore):
     def __iter__(self):
         raise NotImplementedError("cannot iterate over database product store")
 
-    def is_real_time(self) -> bool:
-        return True
-
 
 def load_min_dataset() -> ProductStore:
     ps = MemoryProductStore.load_min()
