@@ -16,7 +16,7 @@ logger = get_logger()
 def run():
     pool: Pool = Pool(settings.WORKER_COUNT, maxtasksperchild=30)
 
-    logger.info("Starting listener server on {}:{}" "".format(*settings.IPC_ADDRESS))
+    logger.info("Starting listener server on {}:{}".format(*settings.IPC_ADDRESS))
     logger.info("Starting listener server")
 
     with Listener(
@@ -24,16 +24,16 @@ def run():
     ) as listener:
         while True:
             try:
-                logger.info("Waiting for a connection...")
+                logger.debug("Waiting for a connection...")
 
                 with listener.accept() as conn:
                     event = conn.recv()
                     event_type: str = event["type"]
-                    logger.info("New '{}' event received".format(event_type))
+                    logger.info(f"New '{event_type}' event received")
                     event_kwargs: Dict = event.get("meta", {})
 
-                    logger.info("Sending task to pool...")
+                    logger.debug("Sending task to pool...")
                     pool.apply_async(run_task, (event_type, event_kwargs))
-                    logger.info("Task sent")
+                    logger.debug("Task sent")
             except Exception:
                 capture_exception()
