@@ -5,38 +5,48 @@ from typing import Optional
 import requests
 
 from robotoff import settings
-from robotoff.insights.dataclass import InsightType
 from robotoff.insights.extraction import (
     get_predictions_from_image,
     get_source_from_image_url,
     predict_objects,
 )
-from robotoff.insights.importer import BaseInsightImporter, InsightImporterFactory
+from robotoff.insights.importer import import_insights
 from robotoff.logos import (
     LOGO_CONFIDENCE_THRESHOLDS,
     add_logos_to_ann,
     import_logo_insights,
     save_nearest_neighbors,
 )
-from robotoff.models import ImageModel, ImagePrediction, LogoAnnotation, db
+from robotoff.models import ImageModel, ImagePrediction, LogoAnnotation, with_db
 from robotoff.off import get_server_type
 from robotoff.prediction.types import PredictionType
 from robotoff.products import Product, get_product_store
 from robotoff.slack import NotifierFactory
 from robotoff.utils import get_logger
-from robotoff.workers.client import send_ipc_event
 
 logger = get_logger(__name__)
 
 
-def import_image(barcode: str, image_url: str, ocr_url: str, server_domain: str):
+def run_import_image_job(
+    barcode: str, image_url: str, ocr_url: str, server_domain: str
+):
     logger.info(
-        "Detect insights for product {}, " "image {}".format(barcode, image_url)
+        f"Running `import_image` for product {barcode} ({server_domain}), image {image_url}"
     )
+    import_image(barcode, image_url, ocr_url, server_domain)
+    # Launch object detection in a new SQL transaction
+    run_object_detection(barcode, image_url, server_domain)
+
+
+@with_db
+def import_image(barcode: str, image_url: str, ocr_url: str, server_domain: str):
     product_store = get_product_store()
     product = product_store[barcode]
-    save_image(barcode, image_url, product, server_domain)
-    launch_object_detection_job(barcode, image_url, server_domain)
+    image = save_image(barcode, image_url, product, server_domain)
+
+    if image is not None:
+        logger.info(f"New image {image.id} created in DB")
+
     predictions_all = get_predictions_from_image(barcode, image_url, ocr_url)
 
     for prediction_type, product_predictions in predictions_all.items():
@@ -48,16 +58,13 @@ def import_image(barcode: str, image_url: str, ocr_url: str, server_domain: str)
             )
             continue
 
-        logger.info("Extracting {}".format(prediction_type.name))
-        importer: BaseInsightImporter = InsightImporterFactory.create(
-            InsightType[prediction_type], product_store
-        )
-
-        with db.atomic():
-            imported = importer.import_insights(
-                [product_predictions], server_domain=server_domain, automatic=True
-            )
-            logger.info("Import finished, {} insights imported".format(imported))
+    imported = import_insights(
+        predictions_all.values(),
+        server_domain,
+        automatic=True,
+        product_store=product_store,
+    )
+    logger.info(f"Import finished, {imported} insights imported")
 
 
 def save_image(
@@ -66,9 +73,7 @@ def save_image(
     """Save imported image details in DB."""
     if product is None:
         logger.warning(
-            "Product {} does not exist during image import ({})".format(
-                barcode, image_url
-            )
+            f"Product {barcode} does not exist during image import ({image_url})"
         )
         return None
 
@@ -76,31 +81,31 @@ def save_image(
     image_id = pathlib.Path(source_image).stem
 
     if not image_id.isdigit():
-        logger.warning("Non raw image was sent: {}".format(image_url))
+        logger.warning(f"Non raw image was sent: {image_url}")
         return None
 
     if image_id not in product.images:
-        logger.warning("Unknown image for product {}: {}".format(barcode, image_url))
+        logger.warning(f"Unknown image for product {barcode}: {image_url}")
         return None
 
     image = product.images[image_id]
     sizes = image.get("sizes", {}).get("full")
 
     if not sizes:
-        logger.warning("Image with missing size information: {}".format(image))
+        logger.warning(f"Image with missing size information: {image}")
         return None
 
     width = sizes["w"]
     height = sizes["h"]
 
     if "uploaded_t" not in image:
-        logger.warning("Missing uploaded_t field: {}".format(image.keys()))
+        logger.warning(f"Missing uploaded_t field: {image.keys()}")
         return None
 
     uploaded_t = image["uploaded_t"]
     if isinstance(uploaded_t, str):
         if not uploaded_t.isdigit():
-            logger.warning("Non digit uploaded_t value: {}".format(uploaded_t))
+            logger.warning(f"Non digit uploaded_t value: {uploaded_t}")
             return None
 
         uploaded_t = int(uploaded_t)
@@ -118,23 +123,28 @@ def save_image(
     )
 
 
-def launch_object_detection_job(barcode: str, image_url: str, server_domain: str):
-    send_ipc_event(
-        "object_detection",
-        {"barcode": barcode, "image_url": image_url, "server_domain": server_domain},
-    )
-
-
+@with_db
 def run_object_detection(barcode: str, image_url: str, server_domain: str):
+    """Detect logos using the universal logo detector model and generate
+    logo-related insights.
+
+    :param barcode: Product barcode
+    :param image_url: URL of the image to use
+    :param server_domain: The server domain associated with the image
+    """
+    logger.info(
+        f"Running object detection for product {barcode} ({server_domain}), "
+        f"image {image_url}"
+    )
     source_image = get_source_from_image_url(image_url)
     image_instance = ImageModel.get_or_none(source_image=source_image)
 
     if image_instance is None:
-        logger.warning("Missing image in DB for image {}".format(image_url))
+        logger.warning(f"Missing image in DB for image {image_url}")
         return
 
     timestamp = datetime.datetime.utcnow()
-    results = predict_objects(barcode, image_url, server_domain)
+    results = predict_objects(image_url)
 
     logos = []
     for model_name, result in results.items():
@@ -159,6 +169,7 @@ def run_object_detection(barcode: str, image_url: str, server_domain: str):
                 )
                 logos.append(logo)
 
+    logger.info(f"{len(logos)} logos found for image {image_url}")
     if logos:
         add_logos_to_ann(image_instance, logos)
 
